@@ -4,11 +4,11 @@ Hqz <- function(Ps, q = 1, Z = diag(length(Ps)), CheckArguments = TRUE)
     CheckentropartArguments()  
   # If names are missing, the probability vector and the similarity vector are assumed to be in the same order
   if (is.null(colnames(Z)) | is.null(names(Ps))) {
-    if (ncol(Z) != length(Ps))
+    if (ncol(as.matrix(Z)) != length(Ps)) # as.matrix(Z) in case it has been reduced to a single value because of zeros
       # The matrix is square (this has been checked)
       stop("The matrix dimension must equal the probability vector length.")    
     # Eliminate zeros
-    Z <- Z[Ps != 0, Ps != 0]
+    Z <- as.matrix(Z)[Ps != 0, Ps != 0]
     Ps <- Ps[Ps != 0]
   } else { # Matrix and Ps are be named.  
     # Eliminate zeros
@@ -16,7 +16,7 @@ Hqz <- function(Ps, q = 1, Z = diag(length(Ps)), CheckArguments = TRUE)
     if (length(setdiff(names(Ps), colnames(Z))) != 0)
       # The matrix is square (this has been checked)
       stop("Some species are missing in the similarity matrix.")    
-    Z <- Z[names(Ps), names(Ps)]
+    Z <- as.matrix(Z)[names(Ps), names(Ps)]
   }
   
   # Calculate (Zp)
