@@ -1,14 +1,14 @@
 summary.DivProfile <-
 function(object, ...) {
   
-  cat("Diversity profile of MetaCommunity", object$MetaCommunity)
+  cat("Diversity profile of MetaCommunity", object$MetaCommunity, fill=TRUE)
   if (!object$Biased)  
     cat(" with correction:", object$Correction)
   cat("\n")
   
   if (!is.null(object$Tree)) {
-    cat("Phylogenetic or functional diversity was calculated according to the tree", object$Tree, "\n")
-    cat("Diversity is", ifelse(object$Normalized, "", "not"), "normalized\n")
+    cat("Phylogenetic or functional diversity was calculated according to the tree", object$Tree, "\n", fill=TRUE)
+    cat("Diversity is", ifelse(object$Normalized, "", "not"), "normalized\n", fill=TRUE)
   }
   
   cat("Diversity against its order:\n")
